@@ -330,8 +330,7 @@ List emmix_t(arma::vec dat, int g=1, int random_starts=4, int max_it=100,
           temp2 = mstep(dat, tau, you, params);
           params = temp2; 
           
-          //params.print();
-          
+
           //log liklihood
           double accumQ1=0;
           double accumQ2=0;
@@ -340,18 +339,10 @@ List emmix_t(arma::vec dat, int g=1, int random_starts=4, int max_it=100,
           mu=params.col(1);
           nu=params.col(2);
           sigma = params.col(3);
-         
 
-          
-          //
-          for(int i=0; i <g; i++){
-              //Rcpp::Rcout << "0.5*(nu.at(i)) = " << 0.5*(nu.at(i)) << std::endl;
-              //Rcpp::Rcout << "boost::math::tgamma(0.5*(nu.at(i))) = " << boost::math::tgamma(0.5*(nu.at(i))) << std::endl;
-             
-              Q2(i) = -std::log(boost::math::tgamma(0.5*(nu.at(i)))) +0.5*nu.at(i) *std::log(0.5*nu.at(i)) - 0.5*nu.at(i)*(boost::math::digamma(0.5*(nu.at(i)+1.0))-std::log (0.5*(nu.at(i)+1.0)) + arma::sum(arma::log(you.row(i))-you.row(i)),1);
+          for(int i=0; i<g; i++){
+              Q2(i) = -std::log(boost::math::tgamma(0.5*(nu.at(i))))  + 0.5*nu.at(i)*std::log(0.5*nu.at(i)) - 0.5*nu.at(i)*(boost::math::digamma(0.5*(nu.at(i)+1.0))-std::log(0.5*(nu.at(i)+1.0)) + arma::sum(arma::log(you.row(i))-you.row(i)));
               Q3.row(i) = -0.5*1.0*std::log(2.0*arma::datum::pi) - 0.5*std::log(std::abs(sigma.at(i))) + 0.5*1.0*arma::log(you.row(i)) - 0.5*you.row(i)*(1.0/sigma.at(i))%((dat-mu.at(i))%(dat-mu.at(i))).t();
-              
-
           }
           
           for(int i=0; i <g; i++){
